@@ -9,6 +9,8 @@ from aiohttp import web
 import time
 import asyncio
 import signal
+import logging
+import traceback
 
 
 class http_server:
@@ -36,9 +38,12 @@ class http_server:
             print("Stoping site ...")
             self.running = False
 
-        loop = asyncio.get_event_loop()
-        for signame in ('SIGINT', 'SIGTERM', 'SIGQUIT'):
-            loop.add_signal_handler(getattr(signal, signame), on_signal)
+        try:
+            loop = asyncio.get_event_loop()
+            for signame in ('SIGINT', 'SIGTERM', 'SIGQUIT'):
+                loop.add_signal_handler(getattr(signal, signame), on_signal)
+        except NotImplementedError:
+            pass
 
         while self.running:
             pre = time.time()
@@ -67,4 +72,3 @@ class http_server:
             self.add_route(method, path, func)
             return func
         return f
-        
